summaryrefslogtreecommitdiff
path: root/sfx2
diff options
context:
space:
mode:
authorAndrea Gelmini <andrea.gelmini@gelma.net>2017-02-13 22:18:09 +0100
committerMichael Stahl <mstahl@redhat.com>2017-02-21 13:34:20 +0000
commit7bc1c438008517cc9d475a21cdc4a06c6d25eb8f (patch)
tree68bc4821920c8da49488058452dd358e6e7a1441 /sfx2
parentcd497ebda3d63042c41e70a9ff8941a0fcf65572 (diff)
Fix typos/translations, following 04644956e53d
No automatic tools Change-Id: I3a6d18760f90c4ee02b9380758f97f6fca6c4428 Reviewed-on: https://gerrit.libreoffice.org/30874 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Michael Stahl <mstahl@redhat.com>
Diffstat (limited to 'sfx2')
-rw-r--r--sfx2/source/bastyp/fltfnc.cxx2
-rw-r--r--sfx2/source/view/viewfrm.cxx4
2 files changed, 3 insertions, 3 deletions
diff --git a/sfx2/source/bastyp/fltfnc.cxx b/sfx2/source/bastyp/fltfnc.cxx
index 3132535768b6..96d1fa17caa8 100644
--- a/sfx2/source/bastyp/fltfnc.cxx
+++ b/sfx2/source/bastyp/fltfnc.cxx
@@ -1117,7 +1117,7 @@ void SfxFilterContainer::ReadFilters_Impl( bool bUpdate )
if( xFilterCFG.is() && xTypeCFG.is() )
{
- // select right query to get right set of filters for search modul
+ // select right query to get right set of filters for search module
uno::Sequence< OUString > lFilterNames = xFilterCFG->getElementNames();
if ( lFilterNames.getLength() )
{
diff --git a/sfx2/source/view/viewfrm.cxx b/sfx2/source/view/viewfrm.cxx
index 0805bd819ff0..3f1b106e6ab3 100644
--- a/sfx2/source/view/viewfrm.cxx
+++ b/sfx2/source/view/viewfrm.cxx
@@ -2404,7 +2404,7 @@ void CutLines( OUString& rStr, sal_Int32 nStartLine, sal_Int32 nLines, bool bEra
/*
add new recorded dispatch macro script into the application global basic
lib container. It generates a new unique id for it and insert the macro
- by using this number as name for the modul
+ by using this number as name for the module
*/
void SfxViewFrame::AddDispatchMacroToBasic_Impl( const OUString& sMacro )
{
@@ -2549,7 +2549,7 @@ void SfxViewFrame::AddDispatchMacroToBasic_Impl( const OUString& sMacro )
sRoutine.append(sMacro);
sRoutine.append( "\nend sub\n" );
// create the modul inside the library and insert the macro routine
aTemp <<= sRoutine.makeStringAndClear();
if ( bReplace )
{
@@ -2549,7 +2549,7 @@ void SfxViewFrame::AddDispatchMacroToBasic_Impl( const OUString& sMacro )
sRoutine.append(sMacro);
sRoutine.append( "\nend sub\n" );
- // create the modul inside the library and insert the macro routine
+ // create the module inside the library and insert the macro routine
aTemp <<= sRoutine.makeStringAndClear();
if ( bReplace )